InAppPurchaseResultSuccess class

Inheritance
Implementers

Constructors

InAppPurchaseResultSuccess({required InAppPurchaseProduct product, InAppPurchaseProfile? profile, String? jwsTransaction})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
jwsTransaction String?
final
product InAppPurchaseProduct
final
profile InAppPurchaseProfile?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited