PaywallLocalizedContent<T> class

Available extensions

Properties

hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
no setter
isNotEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
final
values Map<String, T>
final

Methods

copyWith({T? value, Map<String, T>? values}) PaywallLocalizedContent<T>
localized(Locale locale) PaywallLocalizedContent<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceAll(Pattern from, String replace, {bool? all}) PaywallLocalizedContent<String?>

Available on PaywallLocalizedContent<String?>, provided by the PaywallLocalizedStringExtension extension

resolveWith(T callback(T value)) PaywallLocalizedContent<T>
stringify({bool? all, required double? usdPrice, required double? price, required int unit, required double discountPrice, required String localizedPrice, required String currencyCode}) PaywallLocalizedContent<String?>

Available on PaywallLocalizedContent<String?>, provided by the PaywallLocalizedStringExtension extension

toJson(Object? callback(T? value)) Object?
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

localizer PaywallLocalizeCallback?
getter/setter pair

Static Methods

parse<T>(Object? source) PaywallLocalizedContent<T>?