PaywallState<T extends Object?> class

Constructors

PaywallState({T? primary, T? secondary})
const
PaywallState.all(T? value)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
primary → T?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary → T?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
of(bool? selected) → T?
resolveWith(T callback(T value)) PaywallState<T>
toJson(Object? callback(T? value)) Object?
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

parse<T>(Object? source, T? callback(Object? source), {T? resolveWith(T? value)?}) PaywallState<T>?