PaywallStyle class

Constructors

PaywallStyle({bool selected = false, PaywallState<Alignment?>? alignmentState, PaywallState<Color?>? backgroundColorState, PaywallState<BlendMode?>? blendModeState, PaywallState<double?>? blurState, PaywallState<Border?>? borderState, PaywallState<BorderRadius?>? borderRadiusState, PaywallState<List<BoxShadow>?>? boxShadowState, PaywallState<bool?>? centerState, PaywallState<Color?>? colorState, PaywallState<BoxConstraints?>? constraintsState, PaywallState<Alignment?>? contentAlignmentState, PaywallState<int?>? durationState, PaywallState<int?>? expandedState, PaywallState<bool?>? fittedState, PaywallState<int?>? flexState, PaywallState<Color?>? foregroundColorState, PaywallState<LinearGradient?>? foregroundGradientState, PaywallState<LinearGradient?>? gradientState, PaywallState<double?>? heightState, PaywallState<double?>? heightPercentageState, PaywallState<String?>? imageState, PaywallState<double?>? imageOpacityState, PaywallState<double?>? imageScaleState, PaywallState<PaywallLayoutType?>? layoutState, PaywallState<Alignment?>? layoutAlignmentState, PaywallState<Clip?>? layoutClipBehaviorState, PaywallState<CrossAxisAlignment?>? layoutCrossAxisAlignmentState, PaywallState<Axis?>? layoutDirectionState, PaywallState<MainAxisAlignment?>? layoutMainAxisAlignmentState, PaywallState<MainAxisSize?>? layoutMainAxisSizeState, PaywallState<double?>? layoutRunSpacingState, PaywallState<double?>? layoutSpacingState, PaywallState<StackFit?>? layoutStackFitState, PaywallState<TextBaseline?>? layoutTextBaselineState, PaywallState<VerticalDirection?>? layoutVerticalDirectionState, PaywallState<WrapAlignment?>? layoutWrapAlignmentState, PaywallState<WrapAlignment?>? layoutWrapRunAlignmentState, PaywallState<WrapCrossAlignment?>? layoutWrapCrossAlignmentState, PaywallState<EdgeInsets?>? marginState, PaywallState<int?>? maxLinesState, PaywallState<double?>? opacityState, PaywallState<bool?>? overflowState, PaywallState<EdgeInsets?>? paddingState, PaywallState<PaywallPosition?>? positionState, PaywallState<double?>? scaleState, PaywallState<double?>? sizeState, PaywallState<TextAlign?>? textAlignState, PaywallState<TextStyle?>? textStyleState, PaywallState<double?>? widthState, PaywallState<double?>? widthPercentageState})
const

Properties

alignment Alignment?
no setter
alignmentState PaywallState<Alignment?>?
final
backgroundColor Color?
no setter
backgroundColorState PaywallState<Color?>?
final
blendMode BlendMode?
no setter
blendModeState PaywallState<BlendMode?>?
final
blur double?
no setter
blurState PaywallState<double?>?
final
border Border?
no setter
borderRadius BorderRadius?
no setter
borderRadiusState PaywallState<BorderRadius?>?
final
borderState PaywallState<Border?>?
final
boxShadow List<BoxShadow>?
no setter
boxShadowState PaywallState<List<BoxShadow>?>?
final
center bool?
no setter
centerState PaywallState<bool?>?
final
color Color?
no setter
colorState PaywallState<Color?>?
final
constraints BoxConstraints?
no setter
constraintsState PaywallState<BoxConstraints?>?
final
contentAlignment Alignment?
no setter
contentAlignmentState PaywallState<Alignment?>?
final
dictionary Map<String, dynamic>
no setter
duration int?
no setter
durationState PaywallState<int?>?
final
expanded int?
no setter
expandedState PaywallState<int?>?
final
fitted bool?
no setter
fittedState PaywallState<bool?>?
final
flex int?
no setter
flexState PaywallState<int?>?
final
foregroundColor Color?
no setter
foregroundColorState PaywallState<Color?>?
final
foregroundGradient LinearGradient?
no setter
foregroundGradientState PaywallState<LinearGradient?>?
final
gradient LinearGradient?
no setter
gradientState PaywallState<LinearGradient?>?
final
hashCode int
The hash code for this object.
no setteroverride
height double?
no setter
heightPercentage double?
no setter
heightPercentageState PaywallState<double?>?
final
heightState PaywallState<double?>?
final
image String?
no setter
imageOpacity double?
no setter
imageOpacityState PaywallState<double?>?
final
imageScale double?
no setter
imageScaleState PaywallState<double?>?
final
imageState PaywallState<String?>?
final
layout PaywallLayoutType?
no setter
layoutAlignment Alignment?
no setter
layoutAlignmentState PaywallState<Alignment?>?
final
layoutClipBehavior Clip?
no setter
layoutClipBehaviorState PaywallState<Clip?>?
final
layoutCrossAxisAlignment CrossAxisAlignment?
no setter
layoutCrossAxisAlignmentState PaywallState<CrossAxisAlignment?>?
final
layoutDirection Axis?
no setter
layoutDirectionState PaywallState<Axis?>?
final
layoutMainAxisAlignment MainAxisAlignment?
no setter
layoutMainAxisAlignmentState PaywallState<MainAxisAlignment?>?
final
layoutMainAxisSize MainAxisSize?
no setter
layoutMainAxisSizeState PaywallState<MainAxisSize?>?
final
layoutRunSpacing double?
no setter
layoutRunSpacingState PaywallState<double?>?
final
layoutSpacing double?
no setter
layoutSpacingState PaywallState<double?>?
final
layoutStackFit StackFit?
no setter
layoutStackFitState PaywallState<StackFit?>?
final
layoutState PaywallState<PaywallLayoutType?>?
final
layoutTextBaseline TextBaseline?
no setter
layoutTextBaselineState PaywallState<TextBaseline?>?
final
layoutVerticalDirection VerticalDirection?
no setter
layoutVerticalDirectionState PaywallState<VerticalDirection?>?
final
layoutWrapAlignment WrapAlignment?
no setter
layoutWrapAlignmentState PaywallState<WrapAlignment?>?
final
layoutWrapCrossAlignment WrapCrossAlignment?
no setter
layoutWrapCrossAlignmentState PaywallState<WrapCrossAlignment?>?
final
layoutWrapRunAlignment WrapAlignment?
no setter
layoutWrapRunAlignmentState PaywallState<WrapAlignment?>?
final
margin EdgeInsets?
no setter
marginState PaywallState<EdgeInsets?>?
final
maxLines int?
no setter
maxLinesState PaywallState<int?>?
final
opacity double?
no setter
opacityState PaywallState<double?>?
final
overflow bool?
no setter
overflowState PaywallState<bool?>?
final
padding EdgeInsets?
no setter
paddingState PaywallState<EdgeInsets?>?
final
position PaywallPosition?
no setter
positionState PaywallState<PaywallPosition?>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double?
no setter
scaleState PaywallState<double?>?
final
selected bool
final
size double?
no setter
sizeState PaywallState<double?>?
final
textAlign TextAlign?
no setter
textAlignState PaywallState<TextAlign?>?
final
textStyle TextStyle?
no setter
textStyleState PaywallState<TextStyle?>?
final
width double?
no setter
widthPercentage double?
no setter
widthPercentageState PaywallState<double?>?
final
widthState PaywallState<double?>?
final

Methods

copyWith({bool? selected, PaywallState<Alignment?>? alignmentState, PaywallState<Color?>? backgroundColorState, PaywallState<BlendMode?>? blendModeState, PaywallState<double?>? blurState, PaywallState<Border?>? borderState, PaywallState<BorderRadius?>? borderRadiusState, PaywallState<List<BoxShadow>?>? boxShadowState, PaywallState<bool?>? centerState, PaywallState<Color?>? colorState, PaywallState<BoxConstraints?>? constraintsState, PaywallState<Alignment?>? contentAlignmentState, PaywallState<int?>? expandedState, PaywallState<int?>? durationState, PaywallState<bool?>? fittedState, PaywallState<int?>? flexState, PaywallState<Color?>? foregroundColorState, PaywallState<LinearGradient?>? foregroundGradientState, PaywallState<LinearGradient?>? gradientState, PaywallState<double?>? heightState, PaywallState<double?>? heightPercentageState, PaywallState<String?>? imageState, PaywallState<double?>? imageOpacityState, PaywallState<double?>? imageScaleState, PaywallState<PaywallLayoutType?>? layoutState, PaywallState<Alignment?>? layoutAlignmentState, PaywallState<Clip?>? layoutClipBehaviorState, PaywallState<CrossAxisAlignment?>? layoutCrossAxisAlignmentState, PaywallState<Axis?>? layoutDirectionState, PaywallState<MainAxisAlignment?>? layoutMainAxisAlignmentState, PaywallState<MainAxisSize?>? layoutMainAxisSizeState, PaywallState<double?>? layoutRunSpacingState, PaywallState<double?>? layoutSpacingState, PaywallState<StackFit?>? layoutStackFitState, PaywallState<TextBaseline?>? layoutTextBaselineState, PaywallState<VerticalDirection?>? layoutVerticalDirectionState, PaywallState<WrapAlignment?>? layoutWrapAlignmentState, PaywallState<WrapAlignment?>? layoutWrapRunAlignmentState, PaywallState<WrapCrossAlignment?>? layoutWrapCrossAlignmentState, PaywallState<EdgeInsets?>? marginState, PaywallState<int?>? maxLinesState, PaywallState<double?>? opacityState, PaywallState<bool?>? overflowState, PaywallState<EdgeInsets?>? paddingState, PaywallState<PaywallPosition?>? positionState, PaywallState<double?>? scaleState, PaywallState<double?>? sizeState, PaywallState<TextAlign?>? textAlignState, PaywallState<TextStyle?>? textStyleState, PaywallState<double?>? widthState, PaywallState<double?>? widthPercentageState}) PaywallStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveWith({bool? selected, PaywallScaler? scaler, TextDirection? textDirection}) PaywallStyle
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

parse<T>(Object? source, bool dark) PaywallStyle?