PaywallPosition class
Constructors
Properties
- bottom → double?
-
final
-
dictionary
→ Map<
String, double> ? -
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → double?
-
final
- left → double?
-
final
- right → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → double?
-
final
- width → double?
-
final
Methods
-
copyWith(
{double? width, double? height, double? left, double? top, double? right, double? bottom}) → PaywallPosition -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveWith(
{PaywallScaler? scaler, TextDirection? textDirection}) → PaywallPosition -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override