PaywallTextButtonContent class
Constructors
-
PaywallTextButtonContent(String id, PaywallLocalizedContent<
String> label, [String? url]) -
const
Properties
-
dictionary
→ Map<
String, dynamic> -
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
-
label
→ PaywallLocalizedContent<
String> -
final
- localizedLabel → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String?
-
final
Methods
-
copyWith(
{String? id, PaywallLocalizedContent< String> ? label, String? url}) → PaywallTextButtonContent -
localized(
Locale locale) → PaywallTextButtonContent -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
parse(
Object? source) → PaywallTextButtonContent?